@@ -9,6 +9,7 @@ Authors
 -------
 * MinRK
 """
+from __future__ import print_function
 
 import time
 import numpy
@@ -19,16 +20,15 @@ ctx = zmq.Context()
 
 dev = devices.ThreadDevice(zmq.FORWARDER, zmq.REP, -1)
 dev.bind_in('tcp://127.0.0.1:10111')
-dev.setsockopt_in(zmq.IDENTITY, "whoda")
+dev.setsockopt_in(zmq.IDENTITY, b"whoda")
 dev.start()
 
 #wait for connections
 time.sleep(1)
 
 A = numpy.random.random((2**11,2**12))
-print "starting blocking loop"
+print("starting blocking loop")
 while True:
     tic = time.time()
     numpy.dot(A,A.transpose())
-    print "blocked for %.3f s"%(time.time()-tic)
-
+    print("blocked for %.3f s"%(time.time()-tic))
