@@ -10,37 +10,39 @@ from __future__ import print_function
 
 __author__ = 'Guido Goldstein'
 
-import json
-import os
-import struct
-import sys
 import threading
 import time
 
 import zmq
 from zmq.utils.monitor import recv_monitor_message
 
-line = lambda : print('-' * 40)
 
-def logger(monitor):
-    done = False
-    while monitor.poll(timeout=5000):
-        evt = recv_monitor_message(monitor)
-        print(json.dumps(evt, indent=1))
-        if evt['event'] == zmq.EVENT_MONITOR_STOPPED:
-            break
-    print()
-    print("Logger done!")
-    monitor.close()
+line = lambda: print('-' * 40)
+
 
 print("libzmq-%s" % zmq.zmq_version())
-if zmq.zmq_version_info() < (4,0):
+if zmq.zmq_version_info() < (4, 0):
     raise RuntimeError("monitoring in libzmq version < 4.0 is not supported")
 
+EVENT_MAP = {}
 print("Event names:")
 for name in dir(zmq):
     if name.startswith('EVENT_'):
-        print("%21s : %4i" % (name, getattr(zmq, name)))
+        value = getattr(zmq, name)
+        print("%21s : %4i" % (name, value))
+        EVENT_MAP[value] = name
+
+
+def event_monitor(monitor):
+    while monitor.poll():
+        evt = recv_monitor_message(monitor)
+        evt.update({'description': EVENT_MAP[evt['event']]})
+        print("Event: {}".format(evt))
+        if evt['event'] == zmq.EVENT_MONITOR_STOPPED:
+            break
+    monitor.close()
+    print()
+    print("event monitor thread done!")
 
 
 ctx = zmq.Context().instance()
@@ -49,7 +51,7 @@ req = ctx.socket(zmq.REQ)
 
 monitor = req.get_monitor_socket()
 
-t = threading.Thread(target=logger, args=(monitor,))
+t = threading.Thread(target=event_monitor, args=(monitor,))
 t.start()
 
 line()
@@ -78,13 +80,33 @@ rep.close()
 time.sleep(1)
 
 line()
-print("close req")
-req.close()
-time.sleep(1)
+print("disabling event monitor")
+req.disable_monitor()
 
 line()
-print("joining")
-t.join()
+print("event monitor thread should now terminate")
+
+# Create a new socket to connect to listener, no more
+# events should be observed.
+rep = ctx.socket(zmq.REP)
+
+line()
+print("connect rep")
+rep.connect("tcp://127.0.0.1:6667")
+time.sleep(0.2)
+
+line()
+print("disconnect rep")
+rep.disconnect("tcp://127.0.0.1:6667")
+time.sleep(0.2)
+
+line()
+print("close rep")
+rep.close()
+
+line()
+print("close req")
+req.close()
 
 print("END")
 ctx.term()
