@@ -1,17 +1,8 @@
 """Import basic exposure of libzmq C API as a backend"""
 
-#-----------------------------------------------------------------------------
-#  Copyright (C) 2013 Brian Granger, Min Ragan-Kelley
-#
-#  This file is part of pyzmq
-#
-#  Distributed under the terms of the New BSD License.  The full license is in
-#  the file COPYING.BSD, distributed as part of this software.
-#-----------------------------------------------------------------------------
+# Copyright (C) PyZMQ Developers
+# Distributed under the terms of the Modified BSD License.
 
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
 
 import os
 import platform
@@ -38,9 +29,14 @@ else:
         _ns = select_backend(first)
     except Exception:
         exc_info = sys.exc_info()
+        exc = exc_info[1]
         try:
             _ns = select_backend(second)
         except ImportError:
+            # prevent 'During handling of the above exception...' on py3
+            # can't use `raise ... from` on Python 2
+            if hasattr(exc, '__cause__'):
+                exc.__cause__ = None
             # raise the *first* error, not the fallback
             reraise(*exc_info)
 
