@@ -1,18 +1,9 @@
 # coding: utf-8
 """0MQ Socket pure Python methods."""
 
-#-----------------------------------------------------------------------------
-#  Copyright (C) 2013 Brian Granger, Min Ragan-Kelley
-#
-#  This file is part of pyzmq
-#
-#  Distributed under the terms of the New BSD License.  The full license is in
-#  the file COPYING.BSD, distributed as part of this software.
-#-----------------------------------------------------------------------------
+# Copyright (C) PyZMQ Developers
+# Distributed under the terms of the Modified BSD License.
 
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
 
 import codecs
 import random
@@ -33,6 +24,7 @@ from .constants import (
     int64_sockopt_names,
     int_sockopt_names,
     bytes_sockopt_names,
+    fd_sockopt_names,
 )
 try:
     import cPickle
@@ -41,9 +33,6 @@ except:
     cPickle = None
     import pickle
 
-#-----------------------------------------------------------------------------
-# Code
-#-----------------------------------------------------------------------------
 
 class Socket(SocketBase, AttributeSetter):
     """The ZMQ socket object
@@ -57,6 +46,22 @@ class Socket(SocketBase, AttributeSetter):
         s = ctx.socket(zmq.ROUTER)
     
     """
+    _shadow = False
+    
+    def __del__(self):
+        if not self._shadow:
+            self.close()
+    
+    # socket as context manager:
+    def __enter__(self):
+        """Sockets are context managers
+        
+        .. versionadded:: 14.4
+        """
+        return self
+    
+    def __exit__(self, *args, **kwargs):
+        self.close()
     
     #-------------------------------------------------------------------------
     # Socket creation
@@ -95,6 +100,7 @@ class Socket(SocketBase, AttributeSetter):
             bytes_sockopt_names,
             int_sockopt_names,
             int64_sockopt_names,
+            fd_sockopt_names,
         ):
             keys.extend(collection)
         return keys
@@ -376,7 +382,7 @@ class Socket(SocketBase, AttributeSetter):
     def send_json(self, obj, flags=0, **kwargs):
         """send a Python object as a message using json to serialize
         
-        Keyword arguments are passed on to json.loads
+        Keyword arguments are passed on to json.dumps
         
         Parameters
         ----------
@@ -473,5 +479,13 @@ class Socket(SocketBase, AttributeSetter):
         ret.connect(addr)
         return ret
 
+    def disable_monitor(self):
+        """Shutdown the PAIR socket (created using get_monitor_socket)
+        that is serving socket events.
+        
+        .. versionadded:: 14.4
+        """
+        self.monitor(None, 0)
+
 
 __all__ = ['Socket']
