@@ -2,9 +2,7 @@
 # Copyright (C) PyZMQ Developers
 # Distributed under the terms of the Modified BSD License.
 
-import sys
 import time
-import errno
 import warnings
 
 import zmq
@@ -13,11 +11,6 @@ from zmq.tests import (
 )
 from zmq.utils.strtypes import bytes, unicode
 
-try:
-    from queue import Queue
-except:
-    from Queue import Queue
-
 
 class TestSocket(BaseZMQTestCase):
 
@@ -31,6 +24,21 @@ class TestSocket(BaseZMQTestCase):
         s.close()
         del ctx
     
+    def test_context_manager(self):
+        url = 'inproc://a'
+        with self.Context() as ctx:
+            with ctx.socket(zmq.PUSH) as a:
+                a.bind(url)
+                with ctx.socket(zmq.PULL) as b:
+                    b.connect(url)
+                    msg = b'hi'
+                    a.send(msg)
+                    rcvd = self.recv(b)
+                    self.assertEqual(rcvd, msg)
+                self.assertEqual(b.closed, True)
+            self.assertEqual(a.closed, True)
+        self.assertEqual(ctx.closed, True)
+    
     def test_dir(self):
         ctx = self.Context()
         s = ctx.socket(zmq.PUB)
@@ -169,24 +177,6 @@ class TestSocket(BaseZMQTestCase):
         p.setsockopt(zmq.LINGER, 11)
         self.assertEqual(p.getsockopt(zmq.LINGER), 11)
     
-    def test_poll(self):
-        """test Socket.poll()"""
-        req, rep = self.create_bound_pair(zmq.REQ, zmq.REP)
-        # default flag is POLLIN, nobody has anything to recv:
-        self.assertEqual(req.poll(0), 0)
-        self.assertEqual(rep.poll(0), 0)
-        self.assertEqual(req.poll(0, zmq.POLLOUT), zmq.POLLOUT)
-        self.assertEqual(rep.poll(0, zmq.POLLOUT), 0)
-        self.assertEqual(req.poll(0, zmq.POLLOUT|zmq.POLLIN), zmq.POLLOUT)
-        self.assertEqual(rep.poll(0, zmq.POLLOUT), 0)
-        req.send('hi')
-        self.assertEqual(req.poll(0), 0)
-        self.assertEqual(rep.poll(1), zmq.POLLIN)
-        self.assertEqual(req.poll(0, zmq.POLLOUT), 0)
-        self.assertEqual(rep.poll(0, zmq.POLLOUT), 0)
-        self.assertEqual(req.poll(0, zmq.POLLOUT|zmq.POLLIN), 0)
-        self.assertEqual(rep.poll(0, zmq.POLLOUT), zmq.POLLIN)
-    
     def test_send_unicode(self):
         "test sending unicode objects"
         a,b = self.create_bound_pair(zmq.PAIR, zmq.PAIR)
@@ -410,7 +400,7 @@ class TestSocket(BaseZMQTestCase):
     
     def test_shadow_pyczmq(self):
         try:
-            from pyczmq import zctx, zsocket, zstr
+            from pyczmq import zctx, zsocket
         except Exception:
             raise SkipTest("Requires pyczmq")
         
